@@ -41,7 +41,6 @@ import org.apache.james.mime4j.dom.field.ContentTypeField;
 import org.apache.james.mime4j.dom.field.FieldName;
 import org.apache.james.mime4j.dom.field.ParsedField;
 import org.apache.james.mime4j.field.Fields;
-import org.apache.james.mime4j.message.BodyPartBuilder;
 import org.apache.james.mime4j.message.MultipartBuilder;
 import org.apache.james.mime4j.message.SingleBodyBuilder;
 import org.apache.james.mime4j.stream.Field;
@@ -66,10 +65,11 @@ public abstract class AbstractEntityBuilder {
      * @param field the field to add.
      */
     public AbstractEntityBuilder addField(Field field) {
-        List<Field> values = fieldMap.get(field.getName().toLowerCase(Locale.US));
+        String lowerCasedFieldName = field.getNameLowerCase();
+        List<Field> values = fieldMap.get(lowerCasedFieldName);
         if (values == null) {
             values = new LinkedList<Field>();
-            fieldMap.put(field.getName().toLowerCase(Locale.US), values);
+            fieldMap.put(lowerCasedFieldName, values);
         }
         values.add(field);
         fields.add(field);
@@ -122,12 +122,12 @@ public abstract class AbstractEntityBuilder {
     }
 
     /**
-     * Returns <code>true<code/> if there is at least one explicitly
+     * Returns <code>true</code> if there is at least one explicitly
      * set field with the given name.
      *
      * @param name the field name (e.g. From, Subject).
-     * @return <code>true<code/> if there is at least one explicitly
-     * set field with the given name, <code>false<code/> otherwise.
+     * @return <code>true</code> if there is at least one explicitly
+     * set field with the given name, <code>false</code> otherwise.
      */
     public boolean containsField(String name) {
         List<Field> l = fieldMap.get(name.toLowerCase(Locale.US));
@@ -210,7 +210,7 @@ public abstract class AbstractEntityBuilder {
      * @param field the field to set.
      */
     public AbstractEntityBuilder setField(Field field) {
-        final String lowerCaseName = field.getName().toLowerCase(Locale.US);
+        final String lowerCaseName = field.getNameLowerCase();
         List<Field> l = fieldMap.get(lowerCaseName);
         if (l == null || l.isEmpty()) {
             addField(field);
@@ -256,7 +256,7 @@ public abstract class AbstractEntityBuilder {
      *         type has been set.
      */
     public String getMimeType() {
-        ContentTypeField field = obtainField(FieldName.CONTENT_TYPE);
+        ContentTypeField field = obtainField(FieldName.CONTENT_TYPE_LOWERCASE);
         return field != null ? field.getMimeType() : null;
     }
 
@@ -267,7 +267,7 @@ public abstract class AbstractEntityBuilder {
      *         type has been set.
      */
     public String getCharset() {
-        ContentTypeField field = obtainField(FieldName.CONTENT_TYPE);
+        ContentTypeField field = obtainField(FieldName.CONTENT_TYPE_LOWERCASE);
         return field != null ? field.getCharset() : null;
     }
 
@@ -293,7 +293,7 @@ public abstract class AbstractEntityBuilder {
      * @return the transfer encoding.
      */
     public String getContentTransferEncoding() {
-        ContentTransferEncodingField field = obtainField(FieldName.CONTENT_TRANSFER_ENCODING);
+        ContentTransferEncodingField field = obtainField(FieldName.CONTENT_TRANSFER_ENCODING_LOWERCASE);
         return field != null ? field.getEncoding() : null;
     }
 
@@ -319,7 +319,7 @@ public abstract class AbstractEntityBuilder {
      *         type has been set.
      */
     public String getDispositionType() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getDispositionType() : null;
     }
 
@@ -428,7 +428,7 @@ public abstract class AbstractEntityBuilder {
      *         <code>null</code> if the filename has not been set.
      */
     public String getFilename() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getFilename() : null;
     }
 
@@ -439,7 +439,7 @@ public abstract class AbstractEntityBuilder {
      *         <code>-1</code> if the filename has not been set.
      */
     public long getSize() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getSize() : -1;
     }
 
@@ -450,7 +450,7 @@ public abstract class AbstractEntityBuilder {
      *         <code>null</code> if the filename has not been set.
      */
     public Date getCreationDate() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getCreationDate() : null;
     }
 
@@ -461,7 +461,7 @@ public abstract class AbstractEntityBuilder {
      *         <code>null</code> if the filename has not been set.
      */
     public Date getModificationDate() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getModificationDate() : null;
     }
 
@@ -472,7 +472,7 @@ public abstract class AbstractEntityBuilder {
      *         <code>null</code> if the filename has not been set.
      */
     public Date getReadDate() {
-        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION);
+        ContentDispositionField field = obtainField(FieldName.CONTENT_DISPOSITION_LOWERCASE);
         return field != null ? field.getReadDate() : null;
     }
 
@@ -499,7 +499,7 @@ public abstract class AbstractEntityBuilder {
      * Sets body of this message.  Also sets the content type based on properties of
      * the given {@link org.apache.james.mime4j.dom.Body}.
      *
-     * @param body
+     * @param textBody
      *            the body.
      */
     public AbstractEntityBuilder setBody(TextBody textBody) {
@@ -539,9 +539,9 @@ public abstract class AbstractEntityBuilder {
 
     /**
      * Sets body of this message.  Also sets the content type based on properties of
-     * the given {@link org.apache.james.mime4j.dom.Body}.
+     * the given {@link org.apache.james.mime4j.dom.Message}.
      *
-     * @param body
+     * @param message
      *            the body.
      */
     public AbstractEntityBuilder setBody(Message message) {
@@ -560,9 +560,9 @@ public abstract class AbstractEntityBuilder {
 
     /**
      * Sets body of this message.  Also sets the content type based on properties of
-     * the given {@link org.apache.james.mime4j.dom.Body}.
+     * the given {@link org.apache.james.mime4j.dom.Multipart}.
      *
-     * @param body
+     * @param multipart
      *            the body.
      */
     public AbstractEntityBuilder setBody(Multipart multipart) {
